==> cyphesis-0.5.18.tar.bz2: cyphesis-0.5.18/rulesets/SolidProperty.cpp <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2007 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

// $Id: SolidProperty.cpp,v 1.2 2008-09-08 00:17:09 alriddoch Exp $

#include "SolidProperty.h"

#include "Entity.h"

#include "common/debug.h"

#include <cassert>

static const bool debug_flag = false;

using Atlas::Message::Element;
using Atlas::Message::MapType;
using Atlas::Message::ListType;
using Atlas::Message::FloatType;

SolidProperty::SolidProperty() : PropertyBase(0)
{
}

bool SolidProperty::get(Element & ent) const
{
    ent = (flags() & flag_bool) ? 1 : 0;
    return true;
}

void SolidProperty::set(const Element & ent)
{
    if (ent.isInt()) {
        if (ent.Int() == 0) {
            resetFlags(flag_bool);
        } else {
            setFlags(flag_bool);
        }
    }
}

void SolidProperty::apply(Entity * owner)
{
    owner->m_location.setSolid(flags() & flag_bool);
}

==> cyphesis-0.6.0.tar.bz2: cyphesis-0.6.0/rulesets/SolidProperty.cpp <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2007 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

// $Id: 5ffdbbb75dfbc1302ae66d04bb836383b3ebd310 $

#include "SolidProperty.h"

#include "Entity.h"

#include "common/debug.h"

#include <cassert>

static const bool debug_flag = false;

using Atlas::Message::Element;
using Atlas::Message::MapType;
using Atlas::Message::ListType;
using Atlas::Message::FloatType;

SolidProperty::SolidProperty()
{
}

int SolidProperty::get(Element & ent) const
{
    ent = (flags() & flag_bool) ? 1 : 0;
    return 0;
}

void SolidProperty::set(const Element & ent)
{
    if (ent.isInt()) {
        if (ent.Int() == 0) {
            resetFlags(flag_bool);
        } else {
            setFlags(flag_bool);
        }
    }
}

void SolidProperty::apply(Entity * owner)
{
    owner->m_location.setSolid(flags() & flag_bool);
}
